==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ro/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Activul desemnat catre :name',
    'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile utilizatorilor: user_count. Rețineți că nu puteți modifica propriile atribute ale utilizatorilor utilizând acest formular și trebuie să efectuați modificări individuale ale propriului dvs. utilizator.',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai mulți utilizatori. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'current_assets'    => 'Activele licitate în prezent la acest utilizator',
    'clone'             => 'Cloneaza utilizator',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Editeaza utilizator',
    'filetype_info'     => 'Tipurile de fișiere permise sunt png, gif, jpg, jpeg, doc, docx, pdf, txt, zip și rar.',
    'history_user'      => 'Istoric pentru :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Faceți clic aici pentru a le restaura.',
    'last_login'        => 'Ultima logare',
    'ldap_config_text'  => 'Setările de configurare LDAP pot fi găsite pe Administrator> Setări. Locația selectată (opțional) va fi setată pentru toți utilizatorii importați.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software predat catre :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vezi utilizator :name',
    'usercsv'           => 'Fișier CSV',
    'two_factor_admin_optin_help' => 'Setările dvs. actuale de administrare permit executarea selectivă a autentificării cu două factori.',
    'two_factor_enrolled' => 'Dispozitivul 2FA Înregistrat',
    'two_factor_active'   => '2FA Active',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ro/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Acest utilizator se poate conecta',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Activul desemnat catre :name',
    'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile utilizatorilor: user_count. Rețineți că nu puteți modifica propriile atribute ale utilizatorilor utilizând acest formular și trebuie să efectuați modificări individuale ale propriului dvs. utilizator.',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai mulți utilizatori. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'current_assets'    => 'Activele licitate în prezent la acest utilizator',
    'clone'             => 'Cloneaza utilizator',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Editeaza utilizator',
    'filetype_info'     => 'Tipurile de fișiere permise sunt png, gif, jpg, jpeg, doc, docx, pdf, txt, zip și rar.',
    'history_user'      => 'Istoric pentru :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Faceți clic aici pentru a le restaura.',
    'last_login'        => 'Ultima logare',
    'ldap_config_text'  => 'Setările de configurare LDAP pot fi găsite pe Administrator> Setări. Locația selectată (opțional) va fi setată pentru toți utilizatorii importați.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software predat catre :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vezi utilizator :name',
    'usercsv'           => 'Fișier CSV',
    'two_factor_admin_optin_help' => 'Setările dvs. actuale de administrare permit executarea selectivă a autentificării cu două factori.',
    'two_factor_enrolled' => 'Dispozitivul 2FA Înregistrat',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
